@@ -1,5 +1,9 @@
+"""
+This module builds all of the ASDF extensions which will be registered by `asdf_astropy.integration`,
+via an ``entry-point`` in the ``pyproject.toml`` file.
+"""
+
 from asdf.extension import ManifestExtension
-from astropy.utils import minversion
 
 from .converters.coordinates.angle import AngleConverter, LatitudeConverter, LongitudeConverter
 from .converters.coordinates.earth_location import EarthLocationConverter
@@ -8,7 +12,8 @@ from .converters.coordinates.representation import RepresentationConverter
 from .converters.coordinates.sky_coord import SkyCoordConverter
 from .converters.coordinates.spectral_coord import SpectralCoordConverter
 from .converters.fits.fits import AsdfFitsConverter, AstropyFitsConverter
-from .converters.table.table import AsdfTableConverter, AstropyTableConverter, ColumnConverter
+from .converters.nddata.uncertainty import UncertaintyConverter
+from .converters.table.table import AsdfTableConverter, AstropyTableConverter, ColumnConverter, NdarrayMixinConverter
 from .converters.time.time import TimeConverter
 from .converters.time.time_delta import TimeDeltaConverter
 from .converters.transform.compound import CompoundConverter
@@ -23,8 +28,25 @@ from .converters.transform.rotations import Rotate3DConverter, RotationSequenceC
 from .converters.transform.spline import SplineConverter
 from .converters.transform.tabular import TabularConverter
 from .converters.unit.equivalency import EquivalencyConverter
+from .converters.unit.magunit import MagUnitConverter
 from .converters.unit.quantity import QuantityConverter
 from .converters.unit.unit import UnitConverter
+from .converters.wcs.slicedwcs import SlicedWCSConverter
+from .converters.wcs.wcs import WCSConverter
+
+__all__ = [
+    "TRANSFORM_CONVERTERS",
+    "TRANSFORM_MANIFEST_URIS",
+    "TRANSFORM_EXTENSIONS",
+    "COORDINATES_CONVERTERS",
+    "ASTROPY_CONVERTERS",
+    "COORDINATES_EXTENSIONS",
+    "ASTROPY_EXTENSIONS",
+    "CORE_CONVERTERS",
+    "CORE_MANIFEST_URIS",
+    "CORE_EXTENSIONS",
+    "UNIT_EXTENSIONS",
+]
 
 TRANSFORM_CONVERTERS = [
     # astropy.modeling.core
@@ -365,20 +387,16 @@ TRANSFORM_CONVERTERS = [
     # astropy.modeling.bounding_box
     ModelBoundingBoxConverter(),
     CompoundBoundingBoxConverter(),
+    SimpleTransformConverter(
+        ["tag:stsci.edu:asdf/transform/schechter1d-*"],
+        "astropy.modeling.powerlaws.Schechter1D",
+    ),
 ]
 
-if minversion("astropy", "5.1.0"):
-    TRANSFORM_CONVERTERS.append(
-        SimpleTransformConverter(
-            ["tag:stsci.edu:asdf/transform/schechter1d-*"],
-            "astropy.modeling.powerlaws.Schechter1D",
-        )
-    )
-
-
 # The order here is important; asdf will prefer to use extensions
 # that occur earlier in the list.
 TRANSFORM_MANIFEST_URIS = [
+    "asdf://asdf-format.org/transform/manifests/transform-1.6.0",
     "asdf://asdf-format.org/transform/manifests/transform-1.5.0",
     "asdf://asdf-format.org/transform/manifests/transform-1.4.0",
     "asdf://asdf-format.org/transform/manifests/transform-1.3.0",
@@ -387,7 +405,6 @@ TRANSFORM_MANIFEST_URIS = [
     "asdf://asdf-format.org/transform/manifests/transform-1.0.0",
 ]
 
-
 TRANSFORM_EXTENSIONS = [
     ManifestExtension.from_uri(
         uri,
@@ -457,51 +474,92 @@ COORDINATES_CONVERTERS = [
 
 
 ASTROPY_CONVERTERS = [
-    EquivalencyConverter(),
     UnitsMappingConverter(),
     TimeDeltaConverter(),
     AstropyTableConverter(),
     AstropyFitsConverter(),
+    NdarrayMixinConverter(),
+    UncertaintyConverter(),
+    WCSConverter(),
+    SlicedWCSConverter(),
+]
+
+_COORDINATES_MANIFEST_URIS = [
+    "asdf://asdf-format.org/astronomy/coordinates/manifests/coordinates-1.1.0",
+    "asdf://asdf-format.org/astronomy/coordinates/manifests/coordinates-1.0.0",
+]
+
+COORDINATES_EXTENSIONS = [
+    ManifestExtension.from_uri(
+        manifest_uri,
+        converters=COORDINATES_CONVERTERS,
+    )
+    for manifest_uri in _COORDINATES_MANIFEST_URIS
 ]
 
 
-COORDINATES_EXTENSION = ManifestExtension.from_uri(
-    "asdf://asdf-format.org/astronomy/coordinates/manifests/coordinates-1.0.0",
-    converters=COORDINATES_CONVERTERS,
-)
-
-
-ASTROPY_EXTENSION = ManifestExtension.from_uri(
+_ASTROPY_EXTENSION_MANIFEST_URIS = [
+    "asdf://astropy.org/astropy/manifests/astropy-1.3.0",
+    "asdf://astropy.org/astropy/manifests/astropy-1.2.0",
+    "asdf://astropy.org/astropy/manifests/astropy-1.1.0",
     "asdf://astropy.org/astropy/manifests/astropy-1.0.0",
-    # This prevents a warning about a missing extension when opening
-    # files written by older versions of astropy:
-    legacy_class_names=["astropy.io.misc.asdf.extension.AstropyExtension"],
-    converters=ASTROPY_CONVERTERS,
-)
+]
+
+
+ASTROPY_EXTENSIONS = [
+    ManifestExtension.from_uri(
+        manifest_uri,
+        # This prevents a warning about a missing extension when opening
+        # files written by older versions of astropy:
+        legacy_class_names=["astropy.io.misc.asdf.extension.AstropyExtension"],
+        converters=ASTROPY_CONVERTERS,
+    )
+    for manifest_uri in _ASTROPY_EXTENSION_MANIFEST_URIS
+]
+
 
 # These tags are part of the ASDF Standard,
 # but we want to override serialization here so that users can
 # work with nice astropy objects for those entities.
-
-CORE_CONVERTERS = [
-    QuantityConverter(),
-    TimeConverter(),
-    UnitConverter(),
-    ColumnConverter(),
-    AsdfTableConverter(),
+_FITS_CONVERTERS = [
     AsdfFitsConverter(),
 ]
 
-
-CORE_MANIFEST_URIS = [
-    "asdf://asdf-format.org/core/manifests/core-1.0.0",
-    "asdf://asdf-format.org/core/manifests/core-1.1.0",
-    "asdf://asdf-format.org/core/manifests/core-1.2.0",
-    "asdf://asdf-format.org/core/manifests/core-1.3.0",
-    "asdf://asdf-format.org/core/manifests/core-1.4.0",
-    "asdf://asdf-format.org/core/manifests/core-1.5.0",
-    "asdf://asdf-format.org/core/manifests/core-1.6.0",
+_TIME_CONVERTERS = [
+    TimeConverter(),
 ]
 
+_TABLE_CONVERTERS = [
+    ColumnConverter(),
+    AsdfTableConverter(),
+]
+
+_UNIT_CONVERTERS = [
+    UnitConverter(),
+    EquivalencyConverter(),
+    MagUnitConverter(),
+    QuantityConverter(),
+]
+
+CORE_CONVERTERS = _FITS_CONVERTERS + _TIME_CONVERTERS + _TABLE_CONVERTERS + _UNIT_CONVERTERS
+
+UNIT_EXTENSIONS = [
+    ManifestExtension.from_uri(
+        "asdf://astropy.org/astropy/manifests/units-1.0.0",
+        converters=_UNIT_CONVERTERS,
+    ),
+]
+
+# up to asdf 1.5.0 many tags supported by asdf-astropy
+# were defined in core manifests
+CORE_MANIFEST_URIS = [
+    "asdf://asdf-format.org/astronomy/manifests/astronomy-1.0.0",
+    "asdf://asdf-format.org/core/manifests/core-1.5.0",
+    "asdf://asdf-format.org/core/manifests/core-1.4.0",
+    "asdf://asdf-format.org/core/manifests/core-1.3.0",
+    "asdf://asdf-format.org/core/manifests/core-1.2.0",
+    "asdf://asdf-format.org/core/manifests/core-1.1.0",
+    "asdf://asdf-format.org/core/manifests/core-1.0.0",
+]
 
 CORE_EXTENSIONS = [ManifestExtension.from_uri(u, converters=CORE_CONVERTERS) for u in CORE_MANIFEST_URIS]
